@@ -2,8 +2,9 @@
 Simulates a screenshot of the Textual devtools
 """
 
+from textual_dev.renderables import DevConsoleHeader
+
 from textual.app import App
-from textual.devtools.renderables import DevConsoleHeader
 from textual.widgets import Static
 
 
