@@ -6,7 +6,7 @@ from typing import Generic, Iterable, TypeVar
 
 from typing_extensions import TypeAlias
 
-from .geometry import Region
+from textual.geometry import Region
 
 ValueType = TypeVar("ValueType")
 GridCoordinate: TypeAlias = "tuple[int, int]"
@@ -57,7 +57,7 @@ class SpatialMap(Generic[ValueType]):
         )
 
     def insert(
-        self, regions_and_values: Iterable[tuple[Region, bool, ValueType]]
+        self, regions_and_values: Iterable[tuple[Region, bool, bool, ValueType]]
     ) -> None:
         """Insert values into the Spatial map.
 
@@ -65,17 +65,18 @@ class SpatialMap(Generic[ValueType]):
         indicates fixed regions. Fixed regions don't scroll and are always visible.
 
         Args:
-            regions_and_values: An iterable of (REGION, FIXED, VALUE).
+            regions_and_values: An iterable of (REGION, FIXED, OVERLAY, VALUE).
         """
         append_fixed = self._fixed.append
         get_grid_list = self._map.__getitem__
         _region_to_grid = self._region_to_grid_coordinates
         total_region = self.total_region
-        for region, fixed, value in regions_and_values:
-            total_region = total_region.union(region)
+        for region, fixed, overlay, value in regions_and_values:
             if fixed:
                 append_fixed(value)
             else:
+                if not overlay:
+                    total_region = total_region.union(region)
                 for grid in _region_to_grid(region):
                     get_grid_list(grid).append(value)
         self.total_region = total_region
