@@ -9,18 +9,27 @@ when setting and getting.
 from __future__ import annotations
 
 from operator import attrgetter
-from typing import TYPE_CHECKING, Generic, Iterable, NamedTuple, Sequence, TypeVar, cast
+from typing import (
+    TYPE_CHECKING,
+    Generic,
+    Iterable,
+    Literal,
+    NamedTuple,
+    Sequence,
+    TypeVar,
+    cast,
+)
 
 import rich.errors
 import rich.repr
 from rich.style import Style
 from typing_extensions import TypeAlias
 
-from .._border import normalize_border_value
-from ..color import Color, ColorParseError
-from ..geometry import Spacing, SpacingDimensions, clamp
-from ._error_tools import friendly_list
-from ._help_text import (
+from textual._border import normalize_border_value
+from textual._cells import cell_len
+from textual.color import TRANSPARENT, Color, ColorParseError
+from textual.css._error_tools import friendly_list
+from textual.css._help_text import (
     border_property_help_text,
     color_property_help_text,
     fractional_property_help_text,
@@ -31,9 +40,9 @@ from ._help_text import (
     string_enum_help_text,
     style_flags_property_help_text,
 )
-from .constants import NULL_SPACING, VALID_STYLE_FLAGS
-from .errors import StyleTypeError, StyleValueError
-from .scalar import (
+from textual.css.constants import HATCHES, VALID_STYLE_FLAGS
+from textual.css.errors import StyleTypeError, StyleValueError
+from textual.css.scalar import (
     NULL_SCALAR,
     UNIT_SYMBOL,
     Scalar,
@@ -43,20 +52,23 @@ from .scalar import (
     get_symbols,
     percentage_string_to_float,
 )
-from .transition import Transition
+from textual.css.transition import Transition
+from textual.geometry import NULL_SPACING, Spacing, SpacingDimensions, clamp
 
 if TYPE_CHECKING:
-    from .._layout import Layout
-    from .styles import Styles, StylesBase
+    from textual.canvas import CanvasLineType
+    from textual.layout import Layout
+    from textual.css.styles import StylesBase
 
-from .types import AlignHorizontal, AlignVertical, DockEdge, EdgeType
+from textual.css.types import AlignHorizontal, AlignVertical, DockEdge, EdgeType
 
 BorderDefinition: TypeAlias = (
-    "Sequence[tuple[EdgeType, str | Color] | None] | tuple[EdgeType, str | Color]"
+    "Sequence[tuple[EdgeType, str | Color] | None] | tuple[EdgeType, str | Color] | Literal['none']"
 )
 
 PropertyGetType = TypeVar("PropertyGetType")
 PropertySetType = TypeVar("PropertySetType")
+EnumType = TypeVar("EnumType", covariant=True)
 
 
 class GenericProperty(Generic[PropertyGetType, PropertySetType]):
@@ -90,13 +102,13 @@ class GenericProperty(Generic[PropertyGetType, PropertySetType]):
         # Raise StyleValueError here
         return cast(PropertyGetType, value)
 
-    def __set_name__(self, owner: Styles, name: str) -> None:
+    def __set_name__(self, owner: StylesBase, name: str) -> None:
         self.name = name
 
     def __get__(
         self, obj: StylesBase, objtype: type[StylesBase] | None = None
     ) -> PropertyGetType:
-        return cast(PropertyGetType, obj.get_rule(self.name, self.default))
+        return obj.get_rule(self.name, self.default)  # type: ignore[return-value]
 
     def __set__(self, obj: StylesBase, value: PropertySetType | None) -> None:
         _rich_traceback_omit = True
@@ -138,7 +150,7 @@ class ScalarProperty:
         self.allow_auto = allow_auto
         super().__init__()
 
-    def __set_name__(self, owner: Styles, name: str) -> None:
+    def __set_name__(self, owner: StylesBase, name: str) -> None:
         self.name = name
 
     def __get__(
@@ -153,7 +165,7 @@ class ScalarProperty:
         Returns:
             The Scalar object or ``None`` if it's not set.
         """
-        return cast("Scalar | None", obj.get_rule(self.name))
+        return obj.get_rule(self.name)  # type: ignore[return-value]
 
     def __set__(
         self, obj: StylesBase, value: float | int | Scalar | str | None
@@ -227,13 +239,13 @@ class ScalarListProperty:
         self.percent_unit = percent_unit
         self.refresh_children = refresh_children
 
-    def __set_name__(self, owner: Styles, name: str) -> None:
+    def __set_name__(self, owner: StylesBase, name: str) -> None:
         self.name = name
 
     def __get__(
         self, obj: StylesBase, objtype: type[StylesBase] | None = None
     ) -> tuple[Scalar, ...] | None:
-        return cast("tuple[Scalar, ...]", obj.get_rule(self.name))
+        return obj.get_rule(self.name)  # type: ignore[return-value]
 
     def __set__(
         self, obj: StylesBase, value: str | Iterable[str | float] | None
@@ -287,14 +299,15 @@ class BoxProperty:
 
         Returns:
             A ``tuple[EdgeType, Style]`` containing the string type of the box and
-                it's style. Example types are "rounded", "solid", and "dashed".
+                its style. Example types are "rounded", "solid", and "dashed".
         """
-        return cast(
-            "tuple[EdgeType, Color]",
-            obj.get_rule(self.name) or ("", self._default_color),
-        )
+        return obj.get_rule(self.name) or ("", self._default_color)  # type: ignore[return-value]
 
-    def __set__(self, obj: Styles, border: tuple[EdgeType, str | Color] | None):
+    def __set__(
+        self,
+        obj: StylesBase,
+        border: tuple[EdgeType, str | Color] | Literal["none"] | None,
+    ):
         """Set the box property.
 
         Args:
@@ -304,13 +317,14 @@ class BoxProperty:
                 ``str`` (e.g. ``"blue on #f0f0f0"`` ) or ``Color`` instead.
 
         Raises:
-            StyleSyntaxError: If the string supplied for the color has invalid syntax.
+            StyleValueError: If the string supplied for the color is not a valid color.
         """
-        _rich_traceback_omit = True
 
         if border is None:
             if obj.clear_rule(self.name):
                 obj.refresh(layout=True)
+        elif border == "none":
+            obj.set_rule(self.name, ("", obj.get_rule(self.name)[1]))
         else:
             _type, color = border
             if _type in ("none", "hidden"):
@@ -453,6 +467,16 @@ class BorderProperty:
             clear_rule(left)
             check_refresh()
             return
+        elif border == "none":
+            set_rule = obj.set_rule
+            get_rule = obj.get_rule
+            set_rule(top, ("", get_rule(top)[1]))
+            set_rule(right, ("", get_rule(right)[1]))
+            set_rule(bottom, ("", get_rule(bottom)[1]))
+            set_rule(left, ("", get_rule(left)[1]))
+            check_refresh()
+            return
+
         if isinstance(border, tuple) and len(border) == 2:
             _border = normalize_border_value(border)  # type: ignore
             setattr(obj, top, _border)
@@ -497,6 +521,23 @@ class BorderProperty:
         check_refresh()
 
 
+class KeylineProperty:
+    """Descriptor for getting and setting keyline information."""
+
+    def __get__(
+        self, obj: StylesBase, objtype: type[StylesBase] | None = None
+    ) -> tuple[CanvasLineType, Color]:
+        return obj.get_rule("keyline", ("none", TRANSPARENT))  # type: ignore[return-value]
+
+    def __set__(self, obj: StylesBase, keyline: tuple[str, Color] | None):
+        if keyline is None:
+            if obj.clear_rule("keyline"):
+                obj.refresh(layout=True)
+        else:
+            if obj.set_rule("keyline", keyline):
+                obj.refresh(layout=True)
+
+
 class SpacingProperty:
     """Descriptor for getting and setting spacing properties (e.g. padding and margin)."""
 
@@ -515,7 +556,7 @@ class SpacingProperty:
         Returns:
             The Spacing. If unset, returns the null spacing ``(0, 0, 0, 0)``.
         """
-        return cast(Spacing, obj.get_rule(self.name, NULL_SPACING))
+        return obj.get_rule(self.name, NULL_SPACING)  # type: ignore[return-value]
 
     def __set__(self, obj: StylesBase, spacing: SpacingDimensions | None):
         """Set the Spacing.
@@ -566,11 +607,11 @@ class DockProperty:
             objtype: The ``Styles`` class.
 
         Returns:
-            The dock name as a string, or "" if the rule is not set.
+            The edge name as a string. Returns "none" if unset or if "none" has been explicitly set.
         """
-        return cast(DockEdge, obj.get_rule("dock", ""))
+        return obj.get_rule("dock", "none")  # type: ignore[return-value]
 
-    def __set__(self, obj: Styles, dock_name: str | None):
+    def __set__(self, obj: StylesBase, dock_name: str):
         """Set the Dock property.
 
         Args:
@@ -582,6 +623,37 @@ class DockProperty:
             obj.refresh(layout=True)
 
 
+class SplitProperty:
+    """Descriptor for getting and setting the split property.
+    The split property allows you to specify which edge you want to split.
+    """
+
+    def __get__(
+        self, obj: StylesBase, objtype: type[StylesBase] | None = None
+    ) -> DockEdge:
+        """Get the Split property.
+
+        Args:
+            obj: The ``Styles`` object.
+            objtype: The ``Styles`` class.
+
+        Returns:
+            The edge name as a string. Returns "none" if unset or if "none" has been explicitly set.
+        """
+        return obj.get_rule("split", "none")  # type: ignore[return-value]
+
+    def __set__(self, obj: StylesBase, dock_name: str):
+        """Set the Dock property.
+
+        Args:
+            obj: The ``Styles`` object.
+            dock_name: The name of the dock to attach this widget to.
+        """
+        _rich_traceback_omit = True
+        if obj.set_rule("split", dock_name):
+            obj.refresh(layout=True)
+
+
 class LayoutProperty:
     """Descriptor for getting and setting layout."""
 
@@ -598,7 +670,7 @@ class LayoutProperty:
         Returns:
             The ``Layout`` object.
         """
-        return cast("Layout | None", obj.get_rule(self.name))
+        return obj.get_rule(self.name)  # type: ignore[return-value]
 
     def __set__(self, obj: StylesBase, layout: str | Layout | None):
         """
@@ -608,16 +680,16 @@ class LayoutProperty:
                 or a ``Layout`` object.
         """
 
-        from ..layouts.factory import Layout  # Prevents circular import
-        from ..layouts.factory import MissingLayout, get_layout
+        from textual.layouts.factory import Layout  # Prevents circular import
+        from textual.layouts.factory import MissingLayout, get_layout
 
         _rich_traceback_omit = True
         if layout is None:
             if obj.clear_rule("layout"):
-                obj.refresh(layout=True)
+                obj.refresh(layout=True, children=True)
         elif isinstance(layout, Layout):
             if obj.set_rule("layout", layout):
-                obj.refresh(layout=True)
+                obj.refresh(layout=True, children=True)
         else:
             try:
                 layout_object = get_layout(layout)
@@ -627,7 +699,7 @@ class LayoutProperty:
                     help_text=layout_property_help_text(self.name, context="inline"),
                 )
             if obj.set_rule("layout", layout_object):
-                obj.refresh(layout=True)
+                obj.refresh(layout=True, children=True)
 
 
 class OffsetProperty:
@@ -652,7 +724,7 @@ class OffsetProperty:
             The ``ScalarOffset`` indicating the adjustment that
                 will be made to widget position prior to it being rendered.
         """
-        return cast("ScalarOffset", obj.get_rule(self.name, NULL_SCALAR))
+        return obj.get_rule(self.name, NULL_SCALAR)  # type: ignore[return-value]
 
     def __set__(
         self, obj: StylesBase, offset: tuple[int | str, int | str] | ScalarOffset | None
@@ -702,7 +774,7 @@ class OffsetProperty:
                 obj.refresh(layout=True)
 
 
-class StringEnumProperty:
+class StringEnumProperty(Generic[EnumType]):
     """Descriptor for getting and setting string properties and ensuring that the set
     value belongs in the set of valid values.
 
@@ -716,7 +788,7 @@ class StringEnumProperty:
     def __init__(
         self,
         valid_values: set[str],
-        default: str,
+        default: EnumType,
         layout: bool = False,
         refresh_children: bool = False,
         refresh_parent: bool = False,
@@ -730,7 +802,9 @@ class StringEnumProperty:
     def __set_name__(self, owner: StylesBase, name: str) -> None:
         self.name = name
 
-    def __get__(self, obj: StylesBase, objtype: type[StylesBase] | None = None) -> str:
+    def __get__(
+        self, obj: StylesBase, objtype: type[StylesBase] | None = None
+    ) -> EnumType:
         """Get the string property, or the default value if it's not set.
 
         Args:
@@ -740,12 +814,12 @@ class StringEnumProperty:
         Returns:
             The string property value.
         """
-        return cast(str, obj.get_rule(self.name, self._default))
+        return obj.get_rule(self.name, self._default)  # type: ignore
 
     def _before_refresh(self, obj: StylesBase, value: str | None) -> None:
         """Do any housekeeping before asking for a layout refresh after a value change."""
 
-    def __set__(self, obj: StylesBase, value: str | None = None):
+    def __set__(self, obj: StylesBase, value: EnumType | None = None):
         """Set the string property and ensure it is in the set of allowed values.
 
         Args:
@@ -787,7 +861,7 @@ class OverflowProperty(StringEnumProperty):
     """Descriptor for overflow styles that forces widgets to refresh scrollbars."""
 
     def _before_refresh(self, obj: StylesBase, value: str | None) -> None:
-        from ..widget import Widget  # Avoid circular import
+        from textual.widget import Widget  # Avoid circular import
 
         if isinstance(obj.node, Widget):
             obj.node._refresh_scrollbars()
@@ -809,7 +883,7 @@ class NameProperty:
         Returns:
             The name.
         """
-        return cast(str, obj.get_rule(self.name, ""))
+        return obj.get_rule(self.name, "")  # type: ignore[return-value]
 
     def __set__(self, obj: StylesBase, name: str | None):
         """Set the name property.
@@ -839,7 +913,7 @@ class NameListProperty:
     def __get__(
         self, obj: StylesBase, objtype: type[StylesBase] | None = None
     ) -> tuple[str, ...]:
-        return cast("tuple[str, ...]", obj.get_rule(self.name, ()))
+        return obj.get_rule(self.name, ())  # type: ignore[return-value]
 
     def __set__(self, obj: StylesBase, names: str | tuple[str] | None = None):
         _rich_traceback_omit = True
@@ -877,9 +951,9 @@ class ColorProperty:
         Returns:
             The Color.
         """
-        return cast(Color, obj.get_rule(self.name, self._default_color))
+        return obj.get_rule(self.name, self._default_color)  # type: ignore[return-value]
 
-    def __set__(self, obj: StylesBase, color: Color | str | None):
+    def __set__(self, obj: StylesBase, color: Color | str | None) -> None:
         """Set the Color.
 
         Args:
@@ -925,10 +999,31 @@ class ColorProperty:
             raise StyleValueError(f"Invalid color value {color}")
 
 
+class ScrollbarColorProperty(ColorProperty):
+    """A descriptor to set scrollbar color(s)."""
+
+    def __set__(self, obj: StylesBase, color: Color | str | None) -> None:
+        super().__set__(obj, color)
+
+        if obj.node is None:
+            return
+
+        from textual.widget import Widget
+
+        if isinstance(obj.node, Widget):
+            widget = obj.node
+
+            if widget.show_horizontal_scrollbar:
+                widget.horizontal_scrollbar.refresh()
+
+            if widget.show_vertical_scrollbar:
+                widget.vertical_scrollbar.refresh()
+
+
 class StyleFlagsProperty:
     """Descriptor for getting and set style flag properties (e.g. ``bold italic underline``)."""
 
-    def __set_name__(self, owner: Styles, name: str) -> None:
+    def __set_name__(self, owner: StylesBase, name: str) -> None:
         self.name = name
 
     def __get__(
@@ -943,9 +1038,9 @@ class StyleFlagsProperty:
         Returns:
             The ``Style`` object.
         """
-        return cast(Style, obj.get_rule(self.name, Style.null()))
+        return obj.get_rule(self.name, Style.null())  # type: ignore[return-value]
 
-    def __set__(self, obj: StylesBase, style_flags: Style | str | None):
+    def __set__(self, obj: StylesBase, style_flags: Style | str | None) -> None:
         """Set the style using a style flag string.
 
         Args:
@@ -959,10 +1054,10 @@ class StyleFlagsProperty:
         _rich_traceback_omit = True
         if style_flags is None:
             if obj.clear_rule(self.name):
-                obj.refresh()
+                obj.refresh(children=True)
         elif isinstance(style_flags, Style):
             if obj.set_rule(self.name, style_flags):
-                obj.refresh()
+                obj.refresh(children=True)
         else:
             words = [word.strip() for word in style_flags.split(" ")]
             valid_word = VALID_STYLE_FLAGS.__contains__
@@ -986,7 +1081,7 @@ class StyleFlagsProperty:
                     ) from None
                 raise error from None
             if obj.set_rule(self.name, style):
-                obj.refresh()
+                obj.refresh(children=True)
 
 
 class TransitionsProperty:
@@ -1006,9 +1101,11 @@ class TransitionsProperty:
                 e.g. ``{"offset": Transition(...), ...}``. If no transitions have been set, an empty ``dict``
                 is returned.
         """
-        return cast("dict[str, Transition]", obj.get_rule("transitions", {}))
+        return obj.get_rule("transitions", {})  # type: ignore[return-value]
 
-    def __set__(self, obj: Styles, transitions: dict[str, Transition] | None) -> None:
+    def __set__(
+        self, obj: StylesBase, transitions: dict[str, Transition] | None
+    ) -> None:
         _rich_traceback_omit = True
         if transitions is None:
             obj.clear_rule("transitions")
@@ -1021,8 +1118,15 @@ class FractionalProperty:
     string percentage (e.g. '10%'). Values will be clamped to the range (0, 1).
     """
 
-    def __init__(self, default: float = 1.0):
+    def __init__(self, default: float = 1.0, children: bool = False):
+        """
+        Args:
+            default: Default value if the rule wasn't explicitly set.
+            children: If `True`, then updating this value will also refresh children.
+                Otherwise only this widget will be refreshed.
+        """
         self.default = default
+        self.children = children
 
     def __set_name__(self, owner: StylesBase, name: str) -> None:
         self.name = name
@@ -1037,7 +1141,7 @@ class FractionalProperty:
         Returns:
             The value of the property (in the range (0, 1)).
         """
-        return cast(float, obj.get_rule(self.name, self.default))
+        return obj.get_rule(self.name, self.default)  # type: ignore[return-value]
 
     def __set__(self, obj: StylesBase, value: float | str | None) -> None:
         """Set the property value, clamping it between 0 and 1.
@@ -1051,11 +1155,11 @@ class FractionalProperty:
         name = self.name
         if value is None:
             if obj.clear_rule(name):
-                obj.refresh()
+                obj.refresh(children=self.children)
             return
 
-        if isinstance(value, float):
-            float_value = value
+        if isinstance(value, (int, float)):
+            float_value = float(value)
         elif isinstance(value, str) and value.endswith("%"):
             float_value = float(Scalar.parse(value).value) / 100
         else:
@@ -1064,7 +1168,7 @@ class FractionalProperty:
                 help_text=fractional_property_help_text(name, context="inline"),
             )
         if obj.set_rule(name, clamp(float_value, 0, 1)):
-            obj.refresh()
+            obj.refresh(children=self.children)
 
 
 class AlignProperty:
@@ -1087,3 +1191,40 @@ class AlignProperty:
         horizontal, vertical = value
         setattr(obj, self.horizontal, horizontal)
         setattr(obj, self.vertical, vertical)
+
+
+class HatchProperty:
+    """Property to expose hatch style."""
+
+    def __get__(
+        self, obj: StylesBase, type: type[StylesBase]
+    ) -> tuple[str, Color] | Literal["none"]:
+        return obj.get_rule("hatch")  # type: ignore[return-value]
+
+    def __set__(
+        self, obj: StylesBase, value: tuple[str, Color | str] | Literal["none"] | None
+    ) -> None:
+        _rich_traceback_omit = True
+        if value is None:
+            if obj.clear_rule("hatch"):
+                obj.refresh(children=True)
+            return
+
+        if value == "none":
+            hatch = "none"
+        else:
+            character, color = value
+            if len(character) != 1:
+                try:
+                    character = HATCHES[character]
+                except KeyError:
+                    raise ValueError(
+                        f"Expected a character or hatch value here; found {character!r}"
+                    ) from None
+            if cell_len(character) != 1:
+                raise ValueError("Hatch character must have a cell length of 1")
+            if isinstance(color, str):
+                color = Color.parse(color)
+            hatch = (character, color)
+
+        obj.set_rule("hatch", hatch)
