@@ -4,7 +4,7 @@ Builtin events sent by Textual.
 
 Events may be marked as "Bubbles" and "Verbose".
 See the [events guide](/guide/events/#bubbling) for an explanation of bubbling.
-Verbose events are excluded from the textual console, unless you explicit request them with the `-v` switch as follows:
+Verbose events are excluded from the textual console, unless you explicitly request them with the `-v` switch as follows:
 
 ```
 textual console -v
@@ -13,22 +13,25 @@ textual console -v
 
 from __future__ import annotations
 
+from dataclasses import dataclass
+from pathlib import Path
 from typing import TYPE_CHECKING, Type, TypeVar
 
 import rich.repr
 from rich.style import Style
 
-from ._types import CallbackType
-from .geometry import Offset, Size
-from .keys import _get_key_aliases
-from .message import Message
+from textual._types import CallbackType
+from textual.geometry import Offset, Size
+from textual.keys import _get_key_aliases
+from textual.message import Message
 
 MouseEventT = TypeVar("MouseEventT", bound="MouseEvent")
 
 if TYPE_CHECKING:
-    from .timer import Timer as TimerClass
-    from .timer import TimerCallback
-    from .widget import Widget
+    from textual.dom import DOMNode
+    from textual.timer import Timer as TimerClass
+    from textual.timer import TimerCallback
+    from textual.widget import Widget
 
 
 @rich.repr.auto
@@ -38,6 +41,11 @@ class Event(Message):
 
 @rich.repr.auto
 class Callback(Event, bubble=False, verbose=True):
+    """Sent by Textual to invoke a callback
+    (see [call_next][textual.message_pump.MessagePump.call_next] and
+    [call_later][textual.message_pump.MessagePump.call_later]).
+    """
+
     def __init__(self, callback: CallbackType) -> None:
         self.callback = callback
         super().__init__()
@@ -46,19 +54,19 @@ class Callback(Event, bubble=False, verbose=True):
         yield "callback", self.callback
 
 
-class ShutdownRequest(Event):
-    pass
+@dataclass
+class CursorPosition(Event, bubble=False):
+    """Internal event used to retrieve the terminal's cursor position."""
 
-
-class Shutdown(Event):
-    pass
+    x: int
+    y: int
 
 
 class Load(Event, bubble=False):
     """
     Sent when the App is running but *before* the terminal is in application mode.
 
-    Use this event to run any set up that doesn't require any visuals such as loading
+    Use this event to run any setup that doesn't require any visuals such as loading
     configuration and binding keys.
 
     - [ ] Bubbles
@@ -109,8 +117,11 @@ class Resize(Event, bubble=False):
         container_size: Size | None = None,
     ) -> None:
         self.size = size
+        """The new size of the Widget."""
         self.virtual_size = virtual_size
+        """The virtual size (scrollable size) of the Widget."""
         self.container_size = size if container_size is None else container_size
+        """The size of the Widget's container widget."""
         super().__init__()
 
     def can_replace(self, message: "Message") -> bool:
@@ -125,6 +136,9 @@ class Resize(Event, bubble=False):
 class Compose(Event, bubble=False, verbose=True):
     """Sent to a widget to request it to compose and mount children.
 
+    This event is used internally by Textual.
+    You won't typically need to explicitly handle it,
+
     - [ ] Bubbles
     - [X] Verbose
     """
@@ -139,7 +153,7 @@ class Mount(Event, bubble=False, verbose=False):
 
 
 class Unmount(Event, bubble=False, verbose=False):
-    """Sent when a widget is unmounted and may not longer receive messages.
+    """Sent when a widget is unmounted and may no longer receive messages.
 
     - [ ] Bubbles
     - [ ] Verbose
@@ -147,7 +161,7 @@ class Unmount(Event, bubble=False, verbose=False):
 
 
 class Show(Event, bubble=False):
-    """Sent when a widget has become visible.
+    """Sent when a widget is first displayed.
 
     - [ ] Bubbles
     - [ ] Verbose
@@ -160,13 +174,17 @@ class Hide(Event, bubble=False):
     - [ ] Bubbles
     - [ ] Verbose
 
-    A widget may be hidden by setting its `visible` flag to `False`, if it is no longer in a layout,
-    or if it has been offset beyond the edges of the terminal.
+    Sent when any of the following conditions apply:
+
+    - The widget is removed from the DOM.
+    - The widget is no longer displayed because it has been scrolled or clipped from the terminal or its container.
+    - The widget has its `display` attribute set to `False`.
+    - The widget's `display` style is set to `"none"`.
     """
 
 
 class Ready(Event, bubble=False):
-    """Sent to the app when the DOM is ready.
+    """Sent to the `App` when the DOM is ready and the first frame has been displayed.
 
     - [ ] Bubbles
     - [ ] Verbose
@@ -189,6 +207,7 @@ class MouseCapture(Event, bubble=False):
     def __init__(self, mouse_position: Offset) -> None:
         super().__init__()
         self.mouse_position = mouse_position
+        """The position of the mouse when captured."""
 
     def __rich_repr__(self) -> rich.repr.Result:
         yield None, self.mouse_position
@@ -208,6 +227,7 @@ class MouseRelease(Event, bubble=False):
     def __init__(self, mouse_position: Offset) -> None:
         super().__init__()
         self.mouse_position = mouse_position
+        """The position of the mouse when released."""
 
     def __rich_repr__(self) -> rich.repr.Result:
         yield None, self.mouse_position
@@ -226,10 +246,7 @@ class Key(InputEvent):
 
     Args:
         key: The key that was pressed.
-        character: A printable character or ``None`` if it is not printable.
-
-    Attributes:
-        aliases: The aliases for the key, including the key itself.
+        character: A printable character or `None` if it is not printable.
     """
 
     __slots__ = ["key", "character", "aliases"]
@@ -237,10 +254,13 @@ class Key(InputEvent):
     def __init__(self, key: str, character: str | None) -> None:
         super().__init__()
         self.key = key
+        """The key that was pressed."""
         self.character = (
             (key if len(key) == 1 else None) if character is None else character
         )
+        """A printable character or ``None`` if it is not printable."""
         self.aliases: list[str] = _get_key_aliases(key)
+        """The aliases for the key, including the key itself."""
 
     def __rich_repr__(self) -> rich.repr.Result:
         yield "key", self.key
@@ -264,15 +284,19 @@ class Key(InputEvent):
         """Check if the key is printable (produces a unicode character).
 
         Returns:
-            True if the key is printable.
+            `True` if the key is printable.
         """
         return False if self.character is None else self.character.isprintable()
 
 
 def _key_to_identifier(key: str) -> str:
     """Convert the key string to a name suitable for use as a Python identifier."""
-    if len(key) == 1 and key.isupper():
-        key = f"upper_{key.lower()}"
+    key_no_modifiers = key.split("+")[-1]
+    if len(key_no_modifiers) == 1 and key_no_modifiers.isupper():
+        if "+" in key:
+            key = f"{key.rpartition('+')[0]}+upper_{key_no_modifiers}"
+        else:
+            key = f"upper_{key_no_modifiers}"
     return key.replace("+", "_").lower()
 
 
@@ -327,15 +351,25 @@ class MouseEvent(InputEvent, bubble=True):
     ) -> None:
         super().__init__()
         self.x = x
+        """The relative x coordinate."""
         self.y = y
+        """The relative y coordinate."""
         self.delta_x = delta_x
+        """Change in x since the last message."""
         self.delta_y = delta_y
+        """Change in y since the last message."""
         self.button = button
+        """Indexed of the pressed button."""
         self.shift = shift
+        """`True` if the shift key is pressed."""
         self.meta = meta
+        """`True` if the meta key is pressed."""
         self.ctrl = ctrl
+        """`True` if the ctrl key is pressed."""
         self.screen_x = x if screen_x is None else screen_x
+        """The absolute x coordinate."""
         self.screen_y = y if screen_y is None else screen_y
+        """The absolute y coordinate."""
         self._style = style or Style()
 
     @classmethod
@@ -380,20 +414,12 @@ class MouseEvent(InputEvent, bubble=True):
 
     @property
     def screen_offset(self) -> Offset:
-        """Mouse coordinate relative to the screen.
-
-        Returns:
-            Mouse coordinate.
-        """
+        """Mouse coordinate relative to the screen."""
         return Offset(self.screen_x, self.screen_y)
 
     @property
     def delta(self) -> Offset:
-        """Mouse coordinate delta (change since last event).
-
-        Returns:
-            Mouse coordinate.
-        """
+        """Mouse coordinate delta (change since last event)."""
         return Offset(self.delta_x, self.delta_y)
 
     @property
@@ -416,6 +442,19 @@ class MouseEvent(InputEvent, bubble=True):
         """
         if self.screen_offset not in widget.content_region:
             return None
+        return self.get_content_offset_capture(widget)
+
+    def get_content_offset_capture(self, widget: Widget) -> Offset:
+        """Get offset from a widget's content area.
+
+        This method works even if the offset is outside the widget content region.
+
+        Args:
+            widget: Widget receiving the event.
+
+        Returns:
+            An offset where the origin is at the top left of the content area.
+        """
         return self.offset - widget.gutter.top_left
 
     def _apply_offset(self, x: int, y: int) -> MouseEvent:
@@ -435,10 +474,10 @@ class MouseEvent(InputEvent, bubble=True):
 
 
 @rich.repr.auto
-class MouseMove(MouseEvent, bubble=False, verbose=True):
+class MouseMove(MouseEvent, bubble=True, verbose=True):
     """Sent when the mouse cursor moves.
 
-    - [ ] Bubbles
+    - [X] Bubbles
     - [X] Verbose
     """
 
@@ -462,7 +501,7 @@ class MouseUp(MouseEvent, bubble=True, verbose=True):
 
 
 @rich.repr.auto
-class MouseScrollDown(MouseEvent, bubble=True):
+class MouseScrollDown(MouseEvent, bubble=True, verbose=True):
     """Sent when the mouse wheel is scrolled *down*.
 
     - [X] Bubbles
@@ -471,7 +510,7 @@ class MouseScrollDown(MouseEvent, bubble=True):
 
 
 @rich.repr.auto
-class MouseScrollUp(MouseEvent, bubble=True):
+class MouseScrollUp(MouseEvent, bubble=True, verbose=True):
     """Sent when the mouse wheel is scrolled *up*.
 
     - [X] Bubbles
@@ -515,26 +554,59 @@ class Timer(Event, bubble=False, verbose=True):
         yield "count", self.count
 
 
-class Enter(Event, bubble=False, verbose=True):
+class Enter(Event, bubble=True, verbose=True):
     """Sent when the mouse is moved over a widget.
 
-    - [ ] Bubbles
+    Note that this event bubbles, so a widget may receive this event when the mouse
+    moves over a child widget. Check the `node` attribute for the widget directly under
+    the mouse.
+
+    - [X] Bubbles
     - [X] Verbose
     """
 
+    __slots__ = ["node"]
 
-class Leave(Event, bubble=False, verbose=True):
-    """Sent when the mouse is moved away from a widget.
+    def __init__(self, node: DOMNode) -> None:
+        self.node = node
+        """The node directly under the mouse."""
+        super().__init__()
 
-    - [ ] Bubbles
+    @property
+    def control(self) -> DOMNode:
+        """Alias for the `node` under the mouse."""
+        return self.node
+
+
+class Leave(Event, bubble=True, verbose=True):
+    """Sent when the mouse is moved away from a widget, or if a widget is
+    programmatically disabled while hovered.
+
+    Note that this widget bubbles, so a widget may receive Leave events for any child widgets.
+    Check the `node` parameter for the original widget that was previously under the mouse.
+
+
+    - [X] Bubbles
     - [X] Verbose
     """
 
+    __slots__ = ["node"]
+
+    def __init__(self, node: DOMNode) -> None:
+        self.node = node
+        """The node that was previously directly under the mouse."""
+        super().__init__()
+
+    @property
+    def control(self) -> DOMNode:
+        """Alias for the `node` that was previously under the mouse."""
+        return self.node
+
 
 class Focus(Event, bubble=False):
     """Sent when a widget is focussed.
 
-    - [X] Bubbles
+    - [ ] Bubbles
     - [ ] Verbose
     """
 
@@ -542,11 +614,36 @@ class Focus(Event, bubble=False):
 class Blur(Event, bubble=False):
     """Sent when a widget is blurred (un-focussed).
 
-    - [X] Bubbles
+    - [ ] Bubbles
     - [ ] Verbose
     """
 
 
+class AppFocus(Event, bubble=False):
+    """Sent when the app has focus.
+
+    - [ ] Bubbles
+    - [ ] Verbose
+
+    Note:
+        Only available when running within a terminal that supports
+        `FocusIn`, or when running via textual-web.
+    """
+
+
+class AppBlur(Event, bubble=False):
+    """Sent when the app loses focus.
+
+    - [ ] Bubbles
+    - [ ] Verbose
+
+    Note:
+        Only available when running within a terminal that supports
+        `FocusOut`, or when running via textual-web.
+    """
+
+
+@dataclass
 class DescendantFocus(Event, bubble=True, verbose=True):
     """Sent when a child widget is focussed.
 
@@ -554,7 +651,16 @@ class DescendantFocus(Event, bubble=True, verbose=True):
     - [X] Verbose
     """
 
+    widget: Widget
+    """The widget that was focused."""
 
+    @property
+    def control(self) -> Widget:
+        """The widget that was focused (alias of `widget`)."""
+        return self.widget
+
+
+@dataclass
 class DescendantBlur(Event, bubble=True, verbose=True):
     """Sent when a child widget is blurred.
 
@@ -562,6 +668,14 @@ class DescendantBlur(Event, bubble=True, verbose=True):
     - [X] Verbose
     """
 
+    widget: Widget
+    """The widget that was blurred."""
+
+    @property
+    def control(self) -> Widget:
+        """The widget that was blurred (alias of `widget`)."""
+        return self.widget
+
 
 @rich.repr.auto
 class Paste(Event, bubble=True):
@@ -581,6 +695,7 @@ class Paste(Event, bubble=True):
     def __init__(self, text: str) -> None:
         super().__init__()
         self.text = text
+        """The text that was pasted."""
 
     def __rich_repr__(self) -> rich.repr.Result:
         yield "text", self.text
@@ -600,3 +715,64 @@ class ScreenSuspend(Event, bubble=False):
     - [ ] Bubbles
     - [ ] Verbose
     """
+
+
+@rich.repr.auto
+class Print(Event, bubble=False):
+    """Sent to a widget that is capturing [`print`][print].
+
+    - [ ] Bubbles
+    - [ ] Verbose
+
+    Args:
+        text: Text that was printed.
+        stderr: `True` if the print was to stderr, or `False` for stdout.
+
+    Note:
+        Python's [`print`][print] output can be captured with
+        [`App.begin_capture_print`][textual.app.App.begin_capture_print].
+    """
+
+    def __init__(self, text: str, stderr: bool = False) -> None:
+        super().__init__()
+        self.text = text
+        """The text that was printed."""
+        self.stderr = stderr
+        """`True` if the print was to stderr, or `False` for stdout."""
+
+    def __rich_repr__(self) -> rich.repr.Result:
+        yield self.text
+        yield self.stderr
+
+
+@dataclass
+class DeliveryComplete(Event, bubble=False):
+    """Sent to App when a file has been delivered."""
+
+    key: str
+    """The delivery key associated with the delivery.
+    
+    This is the same key that was returned by `App.deliver_text`/`App.deliver_binary`.
+    """
+
+    path: Path | None = None
+    """The path where the file was saved, or `None` if the path is not available, for
+    example if the file was delivered via web browser.
+    """
+
+    name: str | None = None
+    """Optional name returned to the app to identify the download."""
+
+
+@dataclass
+class DeliveryFailed(Event, bubble=False):
+    """Sent to App when a file delivery fails."""
+
+    key: str
+    """The delivery key associated with the delivery."""
+
+    exception: BaseException
+    """The exception that was raised during the delivery."""
+
+    name: str | None = None
+    """Optional name returned to the app to identify the download."""
