@@ -4,12 +4,12 @@ from typing import TYPE_CHECKING
 
 import rich.repr
 
-from ._types import CallbackType
-from .geometry import Region
-from .message import Message
+from textual._types import CallbackType
+from textual.geometry import Region
+from textual.message import Message
 
 if TYPE_CHECKING:
-    from .widget import Widget
+    from textual.widget import Widget
 
 
 @rich.repr.auto
@@ -17,6 +17,11 @@ class CloseMessages(Message, verbose=True):
     """Requests message pump to close."""
 
 
+@rich.repr.auto
+class Prune(Message, verbose=True, bubble=False):
+    """Ask the node to prune (remove from DOM)."""
+
+
 @rich.repr.auto
 class ExitApp(Message, verbose=True):
     """Exit the app."""
@@ -24,7 +29,9 @@ class ExitApp(Message, verbose=True):
 
 @rich.repr.auto
 class Update(Message, verbose=True):
-    def __init__(self, widget: Widget):
+    """Sent by Textual to request the update of a widget."""
+
+    def __init__(self, widget: Widget) -> None:
         super().__init__()
         self.widget = widget
 
