@@ -1,11 +1,16 @@
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from rich.console import RenderableType
 from rich.protocol import is_renderable
 from rich.text import Text
 
-from ..errors import RenderError
-from ..widget import Widget
+if TYPE_CHECKING:
+    from textual.app import RenderResult
+
+from textual.errors import RenderError
+from textual.widget import Widget
 
 
 def _check_renderable(renderable: object):
@@ -29,13 +34,12 @@ class Static(Widget, inherit_bindings=False):
 
     Args:
         renderable: A Rich renderable, or string containing console markup.
-            Defaults to "".
-        expand: Expand content if required to fill container. Defaults to False.
-        shrink: Shrink content if required to fill container. Defaults to False.
-        markup: True if markup should be parsed and rendered. Defaults to True.
-        name: Name of widget. Defaults to None.
-        id: ID of Widget. Defaults to None.
-        classes: Space separated list of class names. Defaults to None.
+        expand: Expand content if required to fill container.
+        shrink: Shrink content if required to fill container.
+        markup: True if markup should be parsed and rendered.
+        name: Name of widget.
+        id: ID of Widget.
+        classes: Space separated list of class names.
         disabled: Whether the static is disabled or not.
     """
 
@@ -79,8 +83,9 @@ class Static(Widget, inherit_bindings=False):
                 self._renderable = Text(renderable)
         else:
             self._renderable = renderable
+        self.clear_cached_dimensions()
 
-    def render(self) -> RenderableType:
+    def render(self) -> RenderResult:
         """Get a rich renderable for the widget's content.
 
         Returns:
