@@ -3,18 +3,21 @@ from __future__ import annotations
 from asyncio import gather
 from dataclasses import dataclass
 from itertools import zip_longest
+from typing import Awaitable
 
 from rich.repr import Result
 from rich.text import Text, TextType
+from typing_extensions import Final
 
-from ..app import ComposeResult
-from ..await_complete import AwaitComplete
-from ..css.query import NoMatches
-from ..message import Message
-from ..reactive import reactive
-from ..widget import Widget
-from ._content_switcher import ContentSwitcher
-from ._tabs import Tab, Tabs
+from textual import events
+from textual.app import ComposeResult
+from textual.await_complete import AwaitComplete
+from textual.css.query import NoMatches
+from textual.message import Message
+from textual.reactive import reactive
+from textual.widget import Widget
+from textual.widgets._content_switcher import ContentSwitcher
+from textual.widgets._tabs import Tab, Tabs
 
 __all__ = [
     "ContentTab",
@@ -26,7 +29,38 @@ __all__ = [
 class ContentTab(Tab):
     """A Tab with an associated content id."""
 
-    def __init__(self, label: Text, content_id: str, disabled: bool = False):
+    _PREFIX: Final[str] = "--content-tab-"
+    """The prefix given to the tab IDs."""
+
+    @classmethod
+    def add_prefix(cls, content_id: str) -> str:
+        """Add the prefix to the given ID.
+
+        Args:
+            content_id: The ID to add the prefix to.
+
+        Returns:
+            The ID with the prefix added.
+        """
+        return f"{cls._PREFIX}{content_id}" if content_id else content_id
+
+    @classmethod
+    def sans_prefix(cls, content_id: str) -> str:
+        """Remove the prefix from the given ID.
+
+        Args:
+            content_id: The ID to remove the prefix from.
+
+        Returns:
+            The ID with the prefix removed.
+        """
+        return (
+            content_id[len(cls._PREFIX) :]
+            if content_id.startswith(cls._PREFIX)
+            else content_id
+        )
+
+    def __init__(self, label: Text, content_id: str, disabled: bool = False) -> None:
         """Initialize a ContentTab.
 
         Args:
@@ -34,7 +68,7 @@ class ContentTab(Tab):
             content_id: The id of the content associated with the tab.
             disabled: Is the tab disabled?
         """
-        super().__init__(label, id=content_id, disabled=disabled)
+        super().__init__(label, id=self.add_prefix(content_id), disabled=disabled)
 
 
 class ContentTabs(Tabs):
@@ -53,9 +87,78 @@ class ContentTabs(Tabs):
             active: ID of the tab which should be active on start.
             tabbed_content: The associated TabbedContent instance.
         """
-        super().__init__(*tabs, active=active)
+        super().__init__(
+            *tabs, active=active if active is None else ContentTab.add_prefix(active)
+        )
         self.tabbed_content = tabbed_content
 
+    def get_content_tab(self, tab_id: str) -> ContentTab:
+        """Get the `ContentTab` associated with the given `TabPane` ID.
+
+        Args:
+            tab_id: The ID of the tab to get.
+
+        Returns:
+            The tab associated with that ID.
+        """
+        return self.query_one(f"#{ContentTab.add_prefix(tab_id)}", ContentTab)
+
+    def disable(self, tab_id: str) -> Tab:
+        """Disable the indicated tab.
+
+        Args:
+            tab_id: The ID of the [`Tab`][textual.widgets.Tab] to disable.
+
+        Returns:
+            The [`Tab`][textual.widgets.Tab] that was targeted.
+
+        Raises:
+            TabError: If there are any issues with the request.
+        """
+        return super().disable(ContentTab.add_prefix(tab_id))
+
+    def enable(self, tab_id: str) -> Tab:
+        """Enable the indicated tab.
+
+        Args:
+            tab_id: The ID of the [`Tab`][textual.widgets.Tab] to enable.
+
+        Returns:
+            The [`Tab`][textual.widgets.Tab] that was targeted.
+
+        Raises:
+            TabError: If there are any issues with the request.
+        """
+        return super().enable(ContentTab.add_prefix(tab_id))
+
+    def hide(self, tab_id: str) -> Tab:
+        """Hide the indicated tab.
+
+        Args:
+            tab_id: The ID of the [`Tab`][textual.widgets.Tab] to hide.
+
+        Returns:
+            The [`Tab`][textual.widgets.Tab] that was targeted.
+
+        Raises:
+            TabError: If there are any issues with the request.
+        """
+        return super().hide(ContentTab.add_prefix(tab_id))
+
+    def show(self, tab_id: str) -> Tab:
+        """Show the indicated tab.
+
+        Args:
+            tab_id: The ID of the [`Tab`][textual.widgets.Tab] to show.
+
+        Returns:
+            The [`Tab`][textual.widgets.Tab] that was targeted.
+
+        Raises:
+            TabError: If there are any issues with the request.
+        """
+        return super().show(ContentTab.add_prefix(tab_id))
+
 
 class TabPane(Widget):
     """A container for switchable content, with additional title.
@@ -94,6 +197,10 @@ class TabPane(Widget):
     class Enabled(TabPaneMessage):
         """Sent when a tab pane is enabled via its reactive `disabled`."""
 
+    @dataclass
+    class Focused(TabPaneMessage):
+        """Sent when a child widget is focused."""
+
     def __init__(
         self,
         title: TextType,
@@ -122,17 +229,20 @@ class TabPane(Widget):
         """Notify the parent `TabbedContent` that a tab pane was enabled/disabled."""
         self.post_message(self.Disabled(self) if disabled else self.Enabled(self))
 
+    def _on_descendant_focus(self, event: events.DescendantFocus):
+        """Tell TabbedContent parent something is focused in this pane."""
+        self.post_message(self.Focused(self))
+
 
 class TabbedContent(Widget):
     """A container with associated tabs to toggle content visibility."""
 
     DEFAULT_CSS = """
-
     TabbedContent {
         height: auto;
-    }
-    TabbedContent Tabs {
-        dock: top;
+        &> ContentTabs {
+            dock: top;
+        }
     }
     """
 
@@ -142,10 +252,10 @@ class TabbedContent(Widget):
     class TabActivated(Message):
         """Posted when the active tab changes."""
 
-        ALLOW_SELECTOR_MATCH = {"tab"}
+        ALLOW_SELECTOR_MATCH = {"pane"}
         """Additional message attributes that can be used with the [`on` decorator][textual.on]."""
 
-        def __init__(self, tabbed_content: TabbedContent, tab: Tab) -> None:
+        def __init__(self, tabbed_content: TabbedContent, tab: ContentTab) -> None:
             """Initialize message.
 
             Args:
@@ -156,6 +266,8 @@ class TabbedContent(Widget):
             """The `TabbedContent` widget that contains the tab activated."""
             self.tab = tab
             """The `Tab` widget that was selected (contains the tab label)."""
+            self.pane = tabbed_content.get_pane(tab)
+            """The `TabPane` widget that was activated by selecting the tab."""
             super().__init__()
 
         @property
@@ -170,9 +282,14 @@ class TabbedContent(Widget):
         def __rich_repr__(self) -> Result:
             yield self.tabbed_content
             yield self.tab
+            yield self.pane
 
     class Cleared(Message):
-        """Posted when there are no more tab panes."""
+        """Posted when no tab pane is active.
+
+        This can happen if all tab panes are removed or if the currently active tab
+        pane is unset.
+        """
 
         def __init__(self, tabbed_content: TabbedContent) -> None:
             """Initialize message.
@@ -207,31 +324,23 @@ class TabbedContent(Widget):
         Args:
             *titles: Positional argument will be used as title.
             initial: The id of the initial tab, or empty string to select the first tab.
-            name: The name of the button.
-            id: The ID of the button in the DOM.
-            classes: The CSS classes of the button.
-            disabled: Whether the button is disabled or not.
+            name: The name of the tabbed content.
+            id: The ID of the tabbed content in the DOM.
+            classes: The CSS classes of the tabbed content.
+            disabled: Whether the tabbed content is disabled or not.
         """
         self.titles = [self.render_str(title) for title in titles]
         self._tab_content: list[Widget] = []
         self._initial = initial
         super().__init__(name=name, id=id, classes=classes, disabled=disabled)
 
-    def validate_active(self, active: str) -> str:
-        """It doesn't make sense for `active` to be an empty string.
-
-        Args:
-            active: Attribute to be validated.
-
-        Returns:
-            Value of `active`.
-
-        Raises:
-            ValueError: If the active attribute is set to empty string when there are tabs available.
-        """
-        if not active and self.get_child_by_type(ContentSwitcher).current:
-            raise ValueError("'active' tab must not be empty string.")
-        return active
+    @property
+    def active_pane(self) -> TabPane | None:
+        """The currently active pane, or `None` if no pane is active."""
+        active = self.active
+        if not active:
+            return None
+        return self.get_pane(self.active)
 
     @staticmethod
     def _set_id(content: TabPane, new_id: int) -> TabPane:
@@ -254,9 +363,11 @@ class TabbedContent(Widget):
         # Wrap content in a `TabPane` if required.
         pane_content = [
             self._set_id(
-                content
-                if isinstance(content, TabPane)
-                else TabPane(title or self.render_str(f"Tab {index}"), content),
+                (
+                    content
+                    if isinstance(content, TabPane)
+                    else TabPane(title or self.render_str(f"Tab {index}"), content)
+                ),
                 index,
             )
             for index, (title, content) in enumerate(
@@ -317,7 +428,11 @@ class TabbedContent(Widget):
         assert pane.id is not None
         pane.display = False
         return AwaitComplete(
-            tabs.add_tab(ContentTab(pane._title, pane.id), before=before, after=after),
+            tabs.add_tab(
+                ContentTab(pane._title, pane.id),
+                before=before if before is None else ContentTab.add_prefix(before),
+                after=after if after is None else ContentTab.add_prefix(after),
+            ),
             self.get_child_by_type(ContentSwitcher).mount(pane),
         )
 
@@ -331,7 +446,11 @@ class TabbedContent(Widget):
             An optionally awaitable object that waits for the pane to be removed
                 and the Cleared message to be posted.
         """
-        removal_awaitables = [self.get_child_by_type(ContentTabs).remove_tab(pane_id)]
+        removal_awaitables: list[Awaitable] = [
+            self.get_child_by_type(ContentTabs).remove_tab(
+                ContentTab.add_prefix(pane_id)
+            )
+        ]
         try:
             removal_awaitables.append(
                 self.get_child_by_type(ContentSwitcher)
@@ -343,16 +462,7 @@ class TabbedContent(Widget):
             # other means; so allow that to be a no-op.
             pass
 
-        async def _remove_content(cleared_message: TabbedContent.Cleared) -> None:
-            await gather(*removal_awaitables)
-            if self.tab_count == 0:
-                self.post_message(cleared_message)
-
-        # Note that I create the Cleared message out here, rather than in
-        # _remove_content, to ensure that the message's internal
-        # understanding of who the sender is is correct.
-        # https://github.com/Textualize/textual/issues/2750
-        return AwaitComplete(_remove_content(self.Cleared(self)))
+        return AwaitComplete(*removal_awaitables)
 
     def clear_panes(self) -> AwaitComplete:
         """Remove all the panes in the tabbed content.
@@ -366,15 +476,10 @@ class TabbedContent(Widget):
             self.get_child_by_type(ContentSwitcher).remove_children(),
         )
 
-        async def _clear_content(cleared_message: TabbedContent.Cleared) -> None:
+        async def _clear_content() -> None:
             await await_clear
-            self.post_message(cleared_message)
 
-        # Note that I create the Cleared message out here, rather than in
-        # _clear_content, to ensure that the message's internal
-        # understanding of who the sender is is correct.
-        # https://github.com/Textualize/textual/issues/2750
-        return AwaitComplete(_clear_content(self.Cleared(self)))
+        return AwaitComplete(_clear_content())
 
     def compose_add_child(self, widget: Widget) -> None:
         """When using the context manager compose syntax, we want to attach nodes to the switcher.
@@ -389,16 +494,31 @@ class TabbedContent(Widget):
         if self._is_associated_tabs(event.tabs):
             # The message is relevant, so consume it and update state accordingly.
             event.stop()
+            assert event.tab.id is not None
             switcher = self.get_child_by_type(ContentSwitcher)
-            switcher.current = event.tab.id
-            self.active = event.tab.id
+            switcher.current = ContentTab.sans_prefix(event.tab.id)
+            with self.prevent(self.TabActivated):
+                # We prevent TabbedContent.TabActivated because it is also
+                # posted from the watcher for active, we're also about to
+                # post it below too, which is valid as here we're reacting
+                # to what the Tabs are doing. This ensures we don't get
+                # doubled-up messages.
+                self.active = ContentTab.sans_prefix(event.tab.id)
             self.post_message(
                 TabbedContent.TabActivated(
                     tabbed_content=self,
-                    tab=event.tab,
+                    tab=self.get_child_by_type(ContentTabs).get_content_tab(
+                        self.active
+                    ),
                 )
             )
 
+    def _on_tab_pane_focused(self, event: TabPane.Focused) -> None:
+        """One of the panes contains a widget that was programmatically focused."""
+        event.stop()
+        if event.tab_pane.id is not None:
+            self.active = event.tab_pane.id
+
     def _on_tabs_cleared(self, event: Tabs.Cleared) -> None:
         """Called when there are no active tabs. The tabs may have been cleared,
         or they may all be hidden."""
@@ -424,23 +544,81 @@ class TabbedContent(Widget):
 
     def _watch_active(self, active: str) -> None:
         """Switch tabs when the active attributes changes."""
-        with self.prevent(Tabs.TabActivated):
-            self.get_child_by_type(ContentTabs).active = active
-            self.get_child_by_type(ContentSwitcher).current = active
+        with self.prevent(Tabs.TabActivated, Tabs.Cleared):
+            self.get_child_by_type(ContentTabs).active = ContentTab.add_prefix(active)
+        self.get_child_by_type(ContentSwitcher).current = active
+        if active:
+            self.post_message(
+                TabbedContent.TabActivated(
+                    tabbed_content=self,
+                    tab=self.get_child_by_type(ContentTabs).get_content_tab(active),
+                )
+            )
+        else:
+            self.post_message(
+                TabbedContent.Cleared(tabbed_content=self).set_sender(self)
+            )
 
     @property
     def tab_count(self) -> int:
         """Total number of tabs."""
         return self.get_child_by_type(ContentTabs).tab_count
 
+    def get_tab(self, pane_id: str | TabPane) -> Tab:
+        """Get the `Tab` associated with the given ID or `TabPane`.
+
+        Args:
+            pane_id: The ID of the pane, or the pane itself.
+
+        Returns:
+            The Tab associated with the ID.
+
+        Raises:
+            ValueError: Raised if no ID was available.
+        """
+        if target_id := (pane_id if isinstance(pane_id, str) else pane_id.id):
+            return self.get_child_by_type(ContentTabs).get_content_tab(target_id)
+        raise ValueError(
+            "'pane_id' must be a non-empty string or a TabPane with an id."
+        )
+
+    def get_pane(self, pane_id: str | ContentTab) -> TabPane:
+        """Get the `TabPane` associated with the given ID or tab.
+
+        Args:
+            pane_id: The ID of the pane to get, or the Tab it is associated with.
+
+        Returns:
+            The `TabPane` associated with the ID or the given tab.
+
+        Raises:
+            ValueError: Raised if no ID was available.
+        """
+        target_id: str | None = None
+        if isinstance(pane_id, ContentTab):
+            target_id = (
+                pane_id.id if pane_id.id is None else ContentTab.sans_prefix(pane_id.id)
+            )
+        else:
+            target_id = pane_id
+        if target_id:
+            pane = self.get_child_by_type(ContentSwitcher).get_child_by_id(target_id)
+            assert isinstance(pane, TabPane)
+            return pane
+        raise ValueError(
+            "'pane_id' must be a non-empty string or a ContentTab with an id."
+        )
+
     def _on_tabs_tab_disabled(self, event: Tabs.TabDisabled) -> None:
         """Disable the corresponding tab pane."""
+        if event.tabs.parent is not self:
+            return
         event.stop()
         tab_id = event.tab.id or ""
         try:
             with self.prevent(TabPane.Disabled):
                 self.get_child_by_type(ContentSwitcher).get_child_by_id(
-                    tab_id, expect_type=TabPane
+                    ContentTab.sans_prefix(tab_id), expect_type=TabPane
                 ).disabled = True
         except NoMatches:
             return
@@ -448,23 +626,22 @@ class TabbedContent(Widget):
     def _on_tab_pane_disabled(self, event: TabPane.Disabled) -> None:
         """Disable the corresponding tab."""
         event.stop()
-        tab_pane_id = event.tab_pane.id or ""
         try:
             with self.prevent(Tab.Disabled):
-                self.get_child_by_type(ContentTabs).query_one(
-                    f"Tab#{tab_pane_id}"
-                ).disabled = True
+                self.get_tab(event.tab_pane).disabled = True
         except NoMatches:
             return
 
     def _on_tabs_tab_enabled(self, event: Tabs.TabEnabled) -> None:
         """Enable the corresponding tab pane."""
+        if event.tabs.parent is not self:
+            return
         event.stop()
         tab_id = event.tab.id or ""
         try:
             with self.prevent(TabPane.Enabled):
                 self.get_child_by_type(ContentSwitcher).get_child_by_id(
-                    tab_id, expect_type=TabPane
+                    ContentTab.sans_prefix(tab_id), expect_type=TabPane
                 ).disabled = False
         except NoMatches:
             return
@@ -472,12 +649,9 @@ class TabbedContent(Widget):
     def _on_tab_pane_enabled(self, event: TabPane.Enabled) -> None:
         """Enable the corresponding tab."""
         event.stop()
-        tab_pane_id = event.tab_pane.id or ""
         try:
-            with self.prevent(Tab.Enabled):
-                self.get_child_by_type(ContentTabs).query_one(
-                    f"Tab#{tab_pane_id}"
-                ).disabled = False
+            with self.prevent(Tab.Disabled):
+                self.get_tab(event.tab_pane).disabled = False
         except NoMatches:
             return
 
