@@ -3,7 +3,7 @@ import contextlib
 from rich.terminal_theme import DIMMED_MONOKAI, MONOKAI, NIGHT_OWLISH
 
 from textual.app import App, ComposeResult
-from textual.widgets import Button, Input
+from textual.widgets import Button, Input, Static
 
 
 def test_batch_update():
@@ -29,7 +29,7 @@ class MyApp(App):
 
 
 async def test_hover_update_styles():
-    app = MyApp()
+    app = MyApp(ansi_color=False)
     async with app.run_test() as pilot:
         button = app.query_one(Button)
         assert button.pseudo_classes == {
@@ -37,6 +37,9 @@ async def test_hover_update_styles():
             "can-focus",
             "dark",
             "enabled",
+            "first-of-type",
+            "last-of-type",
+            "even",
         }
 
         # Take note of the initial background colour
@@ -50,6 +53,9 @@ async def test_hover_update_styles():
             "dark",
             "enabled",
             "hover",
+            "first-of-type",
+            "last-of-type",
+            "even",
         }
         assert button.styles.background != initial_background
 
@@ -140,3 +146,36 @@ async def test_ansi_theme():
 
         app.dark = True
         assert app.ansi_theme == DIMMED_MONOKAI
+
+
+async def test_early_exit():
+    """Test exiting early doesn't cause issues."""
+    from textual.app import App
+
+    class AppExit(App):
+        def compose(self):
+            yield Static("Hello")
+
+        def on_mount(self) -> None:
+            # Exit after creating app
+            self.exit()
+
+    app = AppExit()
+    async with app.run_test():
+        pass
+
+
+def test_early_exit_inline():
+    """Test exiting early in inline mode doesn't break."""
+    from textual.app import App
+
+    class AppExit(App):
+        def compose(self):
+            yield Static("Hello")
+
+        def on_mount(self) -> None:
+            # Exit after creating app
+            self.exit()
+
+    app = AppExit()
+    app.run(inline=True, inline_no_clear=True)
