@@ -245,8 +245,9 @@ def test_gradient_errors():
 def test_gradient():
     gradient = Gradient(
         (0, Color(255, 0, 0)),
-        (0.5, Color(0, 0, 255)),
+        (0.5, "blue"),
         (1, Color(0, 255, 0)),
+        quality=11,
     )
 
     assert gradient.get_color(-1) == Color(255, 0, 0)
@@ -256,6 +257,35 @@ def test_gradient():
     assert gradient.get_color(0.5) == Color(0, 0, 255)
     assert gradient.get_color(0.7) == Color(0, 101, 153)
 
-    gradient._stops.pop()
-    with pytest.raises(AssertionError):
-        gradient.get_color(1.0)
+
+def test_is_transparent():
+    """Check is_transparent is reporting correctly."""
+    assert Color(0, 0, 0, 0).is_transparent
+    assert Color(20, 20, 30, 0).is_transparent
+    assert not Color(20, 20, 30, a=0.01).is_transparent
+    assert not Color(20, 20, 30, a=1).is_transparent
+    assert not Color(20, 20, 30, 0, ansi=1).is_transparent
+
+
+@pytest.mark.parametrize(
+    "base,tint,expected",
+    [
+        (
+            Color(0, 0, 0),
+            Color(10, 20, 30),
+            Color(10, 20, 30),
+        ),
+        (
+            Color(0, 0, 0, 0.5),
+            Color(255, 255, 255, 0.5),
+            Color(127, 127, 127, 0.5),
+        ),
+        (
+            Color(100, 0, 0, 0.2),
+            Color(0, 100, 0, 0.5),
+            Color(50, 50, 0, 0.2),
+        ),
+    ],
+)
+def test_tint(base: Color, tint: Color, expected: Color) -> None:
+    assert base.tint(tint) == expected
