@@ -12,7 +12,46 @@ from textual.css.query import NoMatches
 from textual.geometry import Offset, Size
 from textual.message import Message
 from textual.widget import BadWidgetName, MountError, PseudoClasses, Widget
-from textual.widgets import Label, LoadingIndicator
+from textual.widgets import (
+    Button,
+    DataTable,
+    Footer,
+    Header,
+    Input,
+    Label,
+    LoadingIndicator,
+    Log,
+    OptionList,
+    RichLog,
+    Switch,
+    TextArea,
+)
+
+
+async def test_widget_construct():
+    """Regression test for https://github.com/Textualize/textual/issues/5042"""
+
+    # Check that constructing the widget outside of the app, doesn't invoke code that
+    # expects an active app.
+    class MyApp(App):
+        def __init__(self) -> None:
+            super().__init__()
+            self.button = Button()
+            self.data_table = DataTable()
+            self.footer = Footer()
+            self.header = Header()
+            self.input = Input()
+            self.label = Label()
+            self.loading_indicator = LoadingIndicator()
+            self.log_ = Log()
+            self.option_list = OptionList()
+            self.rich_log = RichLog()
+            self.switch = Switch()
+            self.text_area = TextArea(language="python")
+
+    app = MyApp()
+    async with app.run_test():
+        pass
 
 
 @pytest.mark.parametrize(
@@ -57,22 +96,21 @@ def test_widget_content_width():
     widget3 = TextWidget("foo\nbar\nbaz", id="widget3")
 
     app = App()
-    app._set_active()
+    with app._context():
+        width = widget1.get_content_width(Size(20, 20), Size(80, 24))
+        height = widget1.get_content_height(Size(20, 20), Size(80, 24), width)
+        assert width == 3
+        assert height == 1
 
-    width = widget1.get_content_width(Size(20, 20), Size(80, 24))
-    height = widget1.get_content_height(Size(20, 20), Size(80, 24), width)
-    assert width == 3
-    assert height == 1
+        width = widget2.get_content_width(Size(20, 20), Size(80, 24))
+        height = widget2.get_content_height(Size(20, 20), Size(80, 24), width)
+        assert width == 3
+        assert height == 2
 
-    width = widget2.get_content_width(Size(20, 20), Size(80, 24))
-    height = widget2.get_content_height(Size(20, 20), Size(80, 24), width)
-    assert width == 3
-    assert height == 2
-
-    width = widget3.get_content_width(Size(20, 20), Size(80, 24))
-    height = widget3.get_content_height(Size(20, 20), Size(80, 24), width)
-    assert width == 3
-    assert height == 3
+        width = widget3.get_content_width(Size(20, 20), Size(80, 24))
+        height = widget3.get_content_height(Size(20, 20), Size(80, 24), width)
+        assert width == 3
+        assert height == 3
 
 
 class GetByIdApp(App):
@@ -87,34 +125,38 @@ class GetByIdApp(App):
             id="parent",
         )
 
+    @property
+    def parent(self) -> Widget:
+        return self.query_one("#parent")
+
 
 @pytest.fixture
 async def hierarchy_app():
     app = GetByIdApp()
-    async with app.run_test():
-        yield app
+    yield app
 
 
-@pytest.fixture
-async def parent(hierarchy_app):
-    yield hierarchy_app.get_widget_by_id("parent")
+async def test_get_child_by_id_gets_first_child(hierarchy_app):
+    async with hierarchy_app.run_test():
+        parent = hierarchy_app.parent
+        child = parent.get_child_by_id(id="child1")
+        assert child.id == "child1"
+        assert child.get_child_by_id(id="grandchild1").id == "grandchild1"
+        assert parent.get_child_by_id(id="child2").id == "child2"
 
 
-def test_get_child_by_id_gets_first_child(parent):
-    child = parent.get_child_by_id(id="child1")
-    assert child.id == "child1"
-    assert child.get_child_by_id(id="grandchild1").id == "grandchild1"
-    assert parent.get_child_by_id(id="child2").id == "child2"
+async def test_get_child_by_id_no_matching_child(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        with pytest.raises(NoMatches):
+            parent.get_child_by_id(id="doesnt-exist")
 
 
-def test_get_child_by_id_no_matching_child(parent):
-    with pytest.raises(NoMatches):
-        parent.get_child_by_id(id="doesnt-exist")
-
-
-def test_get_child_by_id_only_immediate_descendents(parent):
-    with pytest.raises(NoMatches):
-        parent.get_child_by_id(id="grandchild1")
+async def test_get_child_by_id_only_immediate_descendents(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        with pytest.raises(NoMatches):
+            parent.get_child_by_id(id="grandchild1")
 
 
 async def test_get_child_by_type():
@@ -135,51 +177,65 @@ async def test_get_child_by_type():
             app.get_child_by_type(Label)
 
 
-def test_get_widget_by_id_no_matching_child(parent):
-    with pytest.raises(NoMatches):
-        parent.get_widget_by_id(id="i-dont-exist")
+async def test_get_widget_by_id_no_matching_child(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        with pytest.raises(NoMatches):
+            parent.get_widget_by_id(id="i-dont-exist")
 
 
-def test_get_widget_by_id_non_immediate_descendants(parent):
-    result = parent.get_widget_by_id("grandchild1")
-    assert result.id == "grandchild1"
+async def test_get_widget_by_id_non_immediate_descendants(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        result = parent.get_widget_by_id("grandchild1")
+        assert result.id == "grandchild1"
 
 
-def test_get_widget_by_id_immediate_descendants(parent):
-    result = parent.get_widget_by_id("child1")
-    assert result.id == "child1"
+async def test_get_widget_by_id_immediate_descendants(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        result = parent.get_widget_by_id("child1")
+        assert result.id == "child1"
 
 
-def test_get_widget_by_id_doesnt_return_self(parent):
-    with pytest.raises(NoMatches):
-        parent.get_widget_by_id("parent")
+async def test_get_widget_by_id_doesnt_return_self(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        with pytest.raises(NoMatches):
+            parent.get_widget_by_id("parent")
 
 
-def test_get_widgets_app_delegated(hierarchy_app, parent):
+async def test_get_widgets_app_delegated(hierarchy_app):
     # Check that get_child_by_id finds the parent, which is a child of the default Screen
-    queried_parent = hierarchy_app.get_child_by_id("parent")
-    assert queried_parent is parent
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        queried_parent = hierarchy_app.get_child_by_id("parent")
+        assert queried_parent is parent
 
-    # Check that the grandchild (descendant of the default screen) is found
-    grandchild = hierarchy_app.get_widget_by_id("grandchild1")
-    assert grandchild.id == "grandchild1"
+        # Check that the grandchild (descendant of the default screen) is found
+        grandchild = hierarchy_app.get_widget_by_id("grandchild1")
+        assert grandchild.id == "grandchild1"
 
 
-def test_widget_mount_ids_must_be_unique_mounting_all_in_one_go(parent):
-    widget1 = Widget(id="hello")
-    widget2 = Widget(id="hello")
+async def test_widget_mount_ids_must_be_unique_mounting_all_in_one_go(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        widget1 = Widget(id="hello")
+        widget2 = Widget(id="hello")
 
-    with pytest.raises(MountError):
-        parent.mount(widget1, widget2)
+        with pytest.raises(MountError):
+            parent.mount(widget1, widget2)
 
 
-def test_widget_mount_ids_must_be_unique_mounting_multiple_calls(parent):
-    widget1 = Widget(id="hello")
-    widget2 = Widget(id="hello")
+async def test_widget_mount_ids_must_be_unique_mounting_multiple_calls(hierarchy_app):
+    async with hierarchy_app.run_test() as pilot:
+        parent = pilot.app.parent
+        widget1 = Widget(id="hello")
+        widget2 = Widget(id="hello")
 
-    parent.mount(widget1)
-    with pytest.raises(DuplicateIds):
-        parent.mount(widget2)
+        parent.mount(widget1)
+        with pytest.raises(DuplicateIds):
+            parent.mount(widget2)
 
 
 def test_get_pseudo_class_state():
@@ -204,7 +260,7 @@ def test_get_pseudo_class_state_parent_disabled():
 
 def test_get_pseudo_class_state_hover():
     widget = Widget()
-    widget.mouse_over = True
+    widget.mouse_hover = True
     pseudo_classes = widget.get_pseudo_class_state()
     assert pseudo_classes == PseudoClasses(enabled=True, focus=False, hover=True)
 
@@ -369,23 +425,23 @@ async def test_loading():
         app = pilot.app
         label = app.query_one(Label)
         assert label.loading == False
-        assert len(label.query(LoadingIndicator)) == 0
+        assert label._cover_widget is None
 
         label.loading = True
         await pilot.pause()
-        assert len(label.query(LoadingIndicator)) == 1
+        assert label._cover_widget is not None
 
         label.loading = True  # Setting to same value is a null-op
         await pilot.pause()
-        assert len(label.query(LoadingIndicator)) == 1
+        assert label._cover_widget is not None
 
         label.loading = False
         await pilot.pause()
-        assert len(label.query(LoadingIndicator)) == 0
+        assert label._cover_widget is None
 
         label.loading = False  # Setting to same value is a null-op
         await pilot.pause()
-        assert len(label.query(LoadingIndicator)) == 0
+        assert label._cover_widget is None
 
 
 async def test_is_mounted_property():
@@ -444,7 +500,6 @@ async def test_sort_children() -> None:
     """Test the sort_children method."""
 
     class SortApp(App):
-
         def compose(self) -> ComposeResult:
             with Container(id="container"):
                 yield Label("three", id="l3")
@@ -481,7 +536,6 @@ async def test_sort_children_no_key() -> None:
     """Test sorting with no key."""
 
     class SortApp(App):
-
         def compose(self) -> ComposeResult:
             with Container(id="container"):
                 yield Label("three", id="l3")
@@ -522,3 +576,56 @@ def test_bad_widget_name_raised() -> None:
 
         class lowercaseWidget(Widget):
             pass
+
+
+def test_lazy_loading() -> None:
+    """Regression test for https://github.com/Textualize/textual/issues/5077
+
+    Check that the lazy loading magic doesn't break attribute access.
+
+    """
+
+    with pytest.raises(ImportError):
+        from textual.widgets import Foo  # nopycln: import
+
+    from textual import widgets
+    from textual.widgets import Label
+
+    assert not hasattr(widgets, "foo")
+    assert not hasattr(widgets, "bar")
+    assert hasattr(widgets, "Label")
+
+
+async def test_of_type() -> None:
+    class MyApp(App):
+        def compose(self) -> ComposeResult:
+            for ordinal in range(5):
+                yield Label(f"Item {ordinal}")
+
+    app = MyApp()
+    async with app.run_test():
+        labels = list(app.query(Label))
+        assert labels[0].first_of_type
+        assert not labels[0].last_of_type
+        assert labels[0].is_odd
+        assert not labels[0].is_even
+
+        assert not labels[1].first_of_type
+        assert not labels[1].last_of_type
+        assert not labels[1].is_odd
+        assert labels[1].is_even
+
+        assert not labels[2].first_of_type
+        assert not labels[2].last_of_type
+        assert labels[2].is_odd
+        assert not labels[2].is_even
+
+        assert not labels[3].first_of_type
+        assert not labels[3].last_of_type
+        assert not labels[3].is_odd
+        assert labels[3].is_even
+
+        assert not labels[4].first_of_type
+        assert labels[4].last_of_type
+        assert labels[4].is_odd
+        assert not labels[4].is_even
